========================
Page d'aide de Telemeta
========================

.. sectnum::

.. contents:: Table des matières


Préambule
==============

Telemeta est un système de gestion collaborative d'archives sonores. Il a été conçue par le `Centre de Recherche en Ethnomusicologie <http://www.crem-cnrs.fr>`_ et la société `Parisson <http://parisson.com>`_ pour satisfaire les besoins de valorisation des archives audio des laboratoires de recherche mais aussi pour permettre aux chercheurs et aux documentalistes d'indexer mutuellement les fonds d'archives.

Cette plateforme est en version bêta jusqu'au 20 juin 2011.

Les pages d'aides seront publiées après cette date.

D'ici là, en cas de problème, merci de contacter la hotline parisson par e-mail : support@parisson.com
ou bien par tout autre moyen : `parisson.com/contact <http://parisson.com/contact>`_

Pour plus d'informations à propos de Telemeta, voir `telemeta.org <http://telemeta.org>`_
